<?php
$conf['badge_position']   = 'top-left';
$conf['bg_color']         = '#000000';
$conf['text_color']       = '#ffffff';
$conf['opacity']          = 33; // in Prozent (33% Transparenz = 67% Deckkraft)
$conf['custom_text_active'] = 0;
$conf['custom_text']        = '';